View source: R/importDataSet.R
| importDataSet | R Documentation |
Imports a data set to the shiny 'pguIMP' web interface. Extracts import options from a 'pguIMP::file' instance and imports the desired record based on the passed information.
importDataSet(obj = "pgu.file")
obj |
Instance of the R6 class pguIMP::pgu.file. |
A data frame that contains the imported data (tibble::tibble)
Sebastian Malkusch
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.