pgu.exporter: pgu.exporter

pgu.exporterR Documentation

pgu.exporter

Description

A class that writes the results of the pguIMP analysis to an Excel file.

Format

[R6::R6Class] object.

Details

Creates a download file name and saves a list of tibbles to an Excel file. Each tibble is written to a separate sheet. This object is used by the shiny based gui and is not for use in individual R-scripts!

Active bindings

fileName

Returns the fileName. (character)

setFileName

Set the fileName. (character)

suffix

Returns the file suffix. (character)

Methods

Public methods


Method new()

Creates and returns a new 'pgu.exporter' object.

Usage
pgu.exporter$new()
Returns

A new 'pgu.exporter' object. (pguIMP::pgu.exporter)


Method finalize()

Clears the heap and indicates if instance of 'pgu.exporter' is removed from heap.

Usage
pgu.exporter$finalize()

Method print()

Prints instance variables of a 'pgu.exporter' object.

Usage
pgu.exporter$print()
Returns

string


Method extractSuffix()

extracts the suffix from the fileName

Usage
pgu.exporter$extractSuffix()

Method writeDataToExcel()

writes tibble to an excel file of the name fileName.

Usage
pgu.exporter$writeDataToExcel(obj = "list")
Arguments
obj

A tibble or list of tibble. If obj is a list, each member will be written to a seperate sheet.


Method clone()

The objects of this class are cloneable with this method.

Usage
pgu.exporter$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Author(s)

Sebastian Malkusch


pguIMP documentation built on Feb. 20, 2026, 5:08 p.m.