Learn R Programming

pguIMP (version 0.0.0.3)

pgu.filter: pgu.filter

Description

Filter the pguIMP dataset.

Arguments

Format

R6::R6Class object.

Active bindings

colIdx

Returns the instance variable colIdx (numeric)

setColIdx

Sets the instance variable colIdx (numeric)

rowIdx

Returns the instance variable rowIdx (numeric)

setRowIdx

Sets the instance variable rowIdx (numeric)

Methods

Public methods

Method new()

Resets the filter parameter colIdx to the full dataframe.

Resets the filter parameter rowIdx to the full dataframe.

Clears the heap and indicates that instance of pguIMP::pgu.filter is removed from heap.

Creates and returns a new pguIMP::pgu.filter object.

Usage

pgu.filter$new(data_df = "tbl_df")

Arguments

data_df

The data to be analyzed. (tibble::tibble)

Returns

A new pguIMP::pgu.filter object. (pguIMP::pgu.filter)

Method print()

Prints instance variables of a pguIMP::pgu.filter object.

Usage

pgu.filter$print()

Returns

string

Method reset()

Resets the filter parameter colIdx and rowIdx to the full dataframe.

Usage

pgu.filter$reset(data_df = "tbl_df")

Arguments

data_df

The data to be analyzed. (tibble::tibble)

Method predict()

Filters and returns the given data frame.

Usage

pgu.filter$predict(data_df = "tbl_df")

Arguments

data_df

The data to be analyzed. (tibble::tibble)

Returns

The filtered data frame (tibble::tibble)

Method clone()

The objects of this class are cloneable with this method.

Usage

pgu.filter$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Details

The filtering is done by column and row indices. This object is used by the shiny based gui and is not for use in individual R-scripts!