Learn R Programming

pguIMP (version 0.0.0.3)

pgu.importer: pgu.importer

Description

Handles the data import

Arguments

Format

R6::R6Class object.

Active bindings

suffixes

Returns the instance variable suffixes (character)

Methods

Public methods

Method new()

Creates and returns a new pgu.importer object.

Usage

pgu.importer$new()

Returns

A new pgu.importer object. (pguIMP::pgu.importer)

Method finalize()

Clears the heap and indicates that instance of pgu.importer is removed from heap.

Usage

pgu.importer$finalize()

Method print()

Prints instance variables of a pgu.importer object.

Usage

pgu.importer$print()

Returns

string

Method suffixIsKnown()

Takes an instance of pgu.file and tests if the suffix is valid.

Usage

pgu.importer$suffixIsKnown(obj = "pgu.file")

Arguments

obj

instance of pgu.file. (pguIMP::pgu.file)

Returns

test result (logical)

Method importData()

Takes an instance of pgu.file imports a dataset.

Usage

pgu.importer$importData(obj = "pgu.file")

Arguments

obj

instance of pgu.file. (pguIMP::pgu.file)

Returns

data frame (tibble::tibble)

Method importLoq()

Takes an instance of pgu.file imports a loq dataset.

Usage

pgu.importer$importLoq(obj = "pgu.file")

Arguments

obj

instance of pgu.file. (pguIMP::pgu.file)

Returns

data frame (tibble::tibble)

Method importMetadata()

Takes an instance of pgu.file imports a metadata dataset.

Usage

pgu.importer$importMetadata(obj = "pgu.file")

Arguments

obj

instance of pgu.file. (pguIMP::pgu.file)

Returns

data frame (tibble::tibble)

Method clone()

The objects of this class are cloneable with this method.

Usage

pgu.importer$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Details

Menages the import of the pguIMP dataset This object is used by the shiny based gui and is not for use in individual R-scripts!