pgu.limitsOfQuantification: pgu.limitsOfQuantification

pgu.limitsOfQuantificationR Documentation

pgu.limitsOfQuantification

Description

Handles values in the pguIMP dataset that exceed the limits of quantification. This object is used by the shiny based gui and is not for use in individual R-scripts!

Format

R6::R6Class object.

Details

more information

Active bindings

loq

Returns the instance variable loq (tibble::tibble)

setLoq

Sets the instance variable loq (tibble::tibble)

outliers

Returns instance variable outliers (tibble::tibble)

lloqSubstituteAlphabet

Returns the instance variable lloqSubstititeAlphabet (character)

lloqSubstituteAgent

Returns the instance variable lloqSubstituteAgent (character)

setLloqSubstituteAgent

Sets the instance variable lloqSubstituteAgent (character)

uloqSubstituteAlphabet

Returns the instance variable uloqSubstititeAlphabet (character)

uloqSubstituteAgent

Returns the instance variable uloqSubstituteAgent (character)

setUloqSubstituteAgent

Sets the instance variable uloqSubstituteAgent (character)

naHandlingAlphabet

Returns the instance variable naHandlingAlphabet (character)

naHandlingAgent

Returns the instance variable naHandlingAgent (character)

setNaHandlingAgent

Sets the instance variable naHandlingAgent (character)

loqStatistics

Returns the instance variable loqStatistics

Methods

The following public methods are available:

- 'new()': Creates a new pgu.limitsOfQuantification object - 'print()': Prints instance variables - 'reset()': Resets the object - 'fit()': Analyzes data for LOQ violations - 'predict()': Applies LOQ corrections - 'attribute_lloq()', 'attribute_uloq()': Get LOQ values - 'set_attribute_lloq()', 'set_attribute_uloq()': Set LOQ values - 'attribute_outliers()': Get outliers for an attribute - 'plot_loq_distribution()': Plot LOQ statistics - 'attribute_bar_plot()', 'attribute_box_plot_with_subset()', 'attribute_plot()': Create diagnostic plots - 'clone()': Clone the object

Author(s)

Sebastian Malkusch

See Also

Other pguIMP classes: pgu.missings


pguIMP documentation built on Feb. 20, 2026, 5:08 p.m.