pgu.missings: pgu.missings

pgu.missingsR Documentation

pgu.missings

Description

Detects and substitutes missing values from data set.

Format

R6::R6Class object.

Details

Detects missing values in the transformed and normalized data set. This object is used by the shiny based gui and is not for use in individual R-scripts!

Active bindings

imputationParameter

Returns the instance variable imputationParameter (tibble::tibble)

imputationSites

Returns the instance variable imputationSites (tibble::tibble)

one_hot_df

Returns the positions of missings in one_hot encoding (tibble::tibble)

amv

Returns the instance variable amv (numeric)

Methods

The following public methods are available:

- 'new()': Creates a new pgu.missings object - 'print()': Prints instance variables - 'resetImputationParameter()': Resets imputation parameters - 'featureIdx()': Get feature position - 'filterFeatures()': Filter features with missings - 'gatherMeasurements()', 'gatherMissings()', 'gatherExistings()', 'gatherFractionOfMissings()': Gather missing value statistics - 'gatherImputationStatistics()': Collect imputation statistics - 'one_hot()': Create one-hot encoding of missings - 'detectImputationSites()': Detect missing value positions - 'imputationSiteDistribution()': Get missing value distribution - 'imputationSiteHeatMap()': Create missing value heatmap - 'clone()': Clone the object

Author(s)

Sebastian Malkusch

See Also

Other pguIMP classes: pgu.limitsOfQuantification


pguIMP documentation built on Feb. 20, 2026, 5:08 p.m.