Learn R Programming

pguIMP (version 0.0.0.3)

pgu.missingsCharacterizer: pgu.missingsCharacterizer

Description

A class that characterizes the origin of missing values.

Arguments

Format

R6::R6Class object.

Active bindings

featureAlphabet

Returns the instance variable featureAlphabet. (character)

featureAgent

Returns the instance variable featureAgent. (character)

setFeatureAgent

Sets the instance variable featureAgent. (character)

missingsCharacteristics_df

Returns the instance variable missingsCharacteristics_df. (tibble::tibble)

Methods

Public methods

Method new()

Creates and returns a new pgu.missingsCharacterizer object.

Usage

pgu.missingsCharacterizer$new(data_df = "tbl_df")

Arguments

data_df

The data to be analyzed. (tibble::tibble)

Returns

A new pgu.missingsCharacterizer object. (pguIMP::pgu.missingsCharacterizer)

Method finalize()

Clears the heap and indicates if instance of pgu.missingsCharacterizer is removed from heap.

Usage

pgu.missingsCharacterizer$finalize()

Method print()

Prints instance variables of a pgu.missingsCharacterizer object.

Usage

pgu.missingsCharacterizer$print()

Returns

string

Method reset()

Takes a dataframe that will be analyzed using the analyze function and resets the instance variables.

Usage

pgu.missingsCharacterizer$reset(data_df = "tbl_df")

Arguments

data_df

The data to be analyzed. (tibble::tibble)

Method analyze()

resets the instance variables and analyzes a dataframe.

Usage

pgu.missingsCharacterizer$analyze(data_df = "tbl_df", progress = "Progress")

Arguments

data_df

The data to be analyzed. (tibble::tibble)

progress

If shiny is loaded, the analysis' progress is stored within this instance of the shiny Progress class. (shiny::Progress)

Method plot_pair_dist()

Plots the analysis result.

Usage

pgu.missingsCharacterizer$plot_pair_dist(data_df = "tbl_df")

Arguments

data_df

The data to be analyzed. (tibble::tibble)

Method clone()

The objects of this class are cloneable with this method.

Usage

pgu.missingsCharacterizer$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Details

A class that characterizes the origin of missing values. This object is used by the shiny based gui and is not for use in individual R-scripts!