| pgu.normDist | R Documentation |
Compares the distribution of a single attribute's values to normal distribution by using several statistic tests.
[R6::R6Class] object.
The distribution of a single value is tested for normality by Shapiro-Wilk test, Kolmogorov-Smirnov test, Anderson-Darling test. The expectation value and standard deviation of a normal distribution representing the data are determined by maximizing the log Likelihood with respect to the expectation value and standard deviation. This object is used by the shiny based gui and is not for use in individual R-scripts!
featureNameReturns the instance variable featureName. (character)
rawDataReturns the instance variable rawData. (tibble::tibble)
setRawDataSets the instance variable rawData. (tibble::tibble)
histogramReturns the instance variable histogram. (tibble::tibble)
expMuReturns the instance variable expMu. (numeric)
expSigmaReturns the instance variable expSigma. (numeric)
dataPointsReturns the instance variable dataPoints. (numeric)
logLikelihoodReturns the instance variable logLikelihood. (numeric)
degOfFreedomReturns the instance variable degOfFreedom. (numeric)
nReturns the instance variable n. (integer)
bicReturns the instance variable bic. (numeric)
aicReturns the instance variable aic. (numeric)
aiccReturns the instance variable aicc. (numeric)
rmseReturns the instance variable rmse. (numeric)
fitSuccessReturns the instance variable fitSuccess. (logical)
testNamesReturns the instance variable testNames. (character)
testParameterNamesReturns the instance variable testParameterNames. (character)
alphaReturns the instance variable alpha. (numeric)
w.shapiroReturns the instance variable w.shapiro. (numeric)
p.shapiroReturns the instance variable p.shapiro. (numeric)
d.kolmogorowReturns the instance variable d.kolmogorow. (numeric)
p.kolmogorowReturns the instance variable p.kolmogorow. (numeric)
a.andersonReturns the instance variable a.anderson. (numeric)
p.andersonReturns the instance variable p.anderson. (numeric)
new()Creates and returns a new 'pgu.normDist' object.
pgu.normDist$new(data = "tbl_df")
dataThe data to be analyzed. (tibble::tibble)
A new 'pgu.normDist' object. (pguIMP::pgu.normDist)
finalize()Clears the heap and indicates that instance of 'pgu.normDist' is removed from heap.
pgu.normDist$finalize()
print()Prints instance variables of a 'pgu.normDist' object.
pgu.normDist$print()
string
resetNormDist()Resets instance variables
pgu.normDist$resetNormDist(data = "tbl_df")
dataDataframe to be analyzed. (tibble::tibble)
resetFail()Resets instance variables in case of a failed analysis.
pgu.normDist$resetFail()
optimize()Optimizes the logLikelihood between the data and a normal distribution with respect to the expectation value and standard deviation. The quality of the best model is calculated subsequently.
pgu.normDist$optimize()
createHistogram()Creates a histogram from the instance variable 'rawData'. The histogram is stored in the instance variable 'histogram'.
pgu.normDist$createHistogram()
normalQQData()Performes a qq-analysis of the instance variable 'rawData' The qq-analysis is stored in the attributes 'sample_quantile' and 'theoretical_quantile' of the instance variable 'rawData'.
pgu.normDist$normalQQData()
test.shapiro()Performes Shapiro-Wilk's test for normality on the instance variable 'rawData'. The test result is stored in the instance variable 'w.shapiro'. The p-value of the test is stored in the instance variable 'p.shapiro'
pgu.normDist$test.shapiro()
test.kolmogorow()Performes Kolmogorow-Smirnow's test for normality on the instance variable 'rawData'. The test result is stored in the instance variable 'd.kolmogorow'. The p-value of the test is stored in the instance variable 'p.kolmogorow'
pgu.normDist$test.kolmogorow()
test.anderson()Performes Anderson-Darling's test for normality on the instance variable 'rawData'. The test result is stored in the instance variable 'a.anderson'. The p-value of the test is stored in the instance variable 'p.anderson'
pgu.normDist$test.anderson()
fitResult()Returns the result of the classes optimize function in form of a formated string.
pgu.normDist$fitResult()
String of the results of the fitting routine (character)
testResult()Returns the result of the classes test functions in form of a formated string.
pgu.normDist$testResult(testName = "Shapiro-Wilk")
testNameDefines the test which result shall be returned. Can be of type:'Shapiro-Wilk', 'Kolmogorow-Smirnow' or 'Anderson-Darling'. (character)
String of the results of the testing routine (character)
testResultCompendium()Returns the result of the classes test functions 'Shapiro-Wilk', 'Kolmogorow-Smirnow' and 'Anderson-Darling' in form of a formated string. (character)
pgu.normDist$testResultCompendium()
String of the results of the testing routine (character)
plotHistogram()Displays the instance variable 'histogram' in form of a bar plot and overlays the corresponding normal distribution.
pgu.normDist$plotHistogram()
A bar plot. (ggplot2::ggplot)
plotResiduals()Displays the residuals between the instance variable 'histogram' and the corresponding normal distribution.
pgu.normDist$plotResiduals()
A scatter plot. (ggplot2::ggplot)
plotResidualDist()Displays the distribution of the residuals between the distribution of the instance variable 'histogram' in form of a histogram.
pgu.normDist$plotResidualDist()
A bar plot. (ggplot2::ggplot)
plotRawResidualDist()Displays the distribution of the residuals between the distribution of the instance variable 'rawData' in form of a histogram.
pgu.normDist$plotRawResidualDist()
A bar plot. (ggplot2::ggplot)
plotRawDataDist()Displays the distribution of the instance variable 'rawData' in form of a histogram.
pgu.normDist$plotRawDataDist()
A bar plot. (ggplot2::ggplot)
normalQQPlot()Displays a qqplot of the instance variable 'rawData'.
pgu.normDist$normalQQPlot()
A qq-plot. (ggplot2::ggplot)
fit()Runs the optimization process and performs all implemented quality controls. Additionally performs hypothesis tests for normality.
pgu.normDist$fit()
clone()The objects of this class are cloneable with this method.
pgu.normDist$clone(deep = FALSE)
deepWhether to make a deep clone.
Sebastian Malkusch
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.