Learn R Programming

pguIMP (version 0.0.0.3)

pgu.status: pgu.status

Description

A class that keeps track of the pguIMP analysis process.

Arguments

Format

R6::R6Class object.

Active bindings

processAlphabet

Reurns the process alphabet of the pguIMP analysis routine. (character)

processStatus

Returns the process status of the pguIMP routine. (logical)

Methods

Public methods

Method new()

Creates and returns a new `pgu.status`` object.

Usage

pgu.status$new()

Returns

A new pgu.status object. (pguIMP::pgu.status)

Method finalize()

Clears the heap and indicates if instance of pgu.status is removed from heap.

Usage

pgu.status$finalize()

Method print()

Prints instance variables of a pgu.status object.

Usage

pgu.status$print()

Returns

string

Method reset()

resets the intance variables processAlphabet and processStatus to their initial values (FALSE).

Usage

pgu.status$reset()

Method update()

updates the process status

Usage

pgu.status$update(processName = "character", value = "logical")

Arguments

processName

The name of the pguIMP process that has been performed. (character)

value

Indicates if the process ended with success. (logical)

Method query()

Queries if a process has already been performed successfully.

Usage

pgu.status$query(processName = "character")

Arguments

processName

Name of the process to be checked. (character)

Returns

Status of the queried process (logical)

Method clone()

The objects of this class are cloneable with this method.

Usage

pgu.status$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Details

pguIMP uses a defined linear analysis path The current status therefore provides information about which analyses have already been performed and which still have to be performed. This way pguIMG knows any time during analysis, if all necessary information for the next desired analysis step are available. This object is used by the shiny based gui and is not for use in individual R-scripts!