| pgu.validator | R Documentation |
Validates that the distribution is not significantly altered by the imputation process. This object is used by the shiny based gui and is not for use in individual R-scripts!
[R6::R6Class] object.
Takes two distributions (before and after imputation). Performs a Wilcoxon-Mann-Whitney U test. Performs a Kolmogorow-Smirnow test.
testStatistics_dfReturns the instance variable 'testStatistics_df'. (tibble::tibble)
centralMoments_orgReturns the instance variable 'centralMoments_org' (tibble::tibble)
centralMoments_impReturns the instance variable 'centralMoments_imp' (tibble::tibble)
centralMoments_deltaReturns the instance variable 'centralMoments_delta' (tibble::tibble)
featuresReturns the instance variable 'features' (character)
seedReturns the instance variable seed (integer)
setSeedSets the instance variable seed. (numeric)
new()Creates and returns a new 'pgu.validator' object.
pgu.validator$new(seed = 42)
seedSet the instance variable 'seed'. (integer)
A new 'pgu.validator' object. (pguIMP::pgu.validator)
finalize()Clears the heap and indicates that instance of 'pgu.validator' is removed from heap.
pgu.validator$finalize()
print()Prints instance variables of a 'pgu.validator' object.
pgu.validator$print()
string
resetValidator()Resets instance variables
pgu.validator$resetValidator()
kolmogorowTestFeature()Performs a comparison between the original and the imputated distribution of a given feature using a two-sided Kolmorogow-Smirnow test with simulated p-vaue distribution.
pgu.validator$kolmogorowTestFeature( org = "numeric", imp = "numeric", feature = "character" )
orgOriginal data to be analzed. (numeric)
impImputed data to be analyzed. (numeric)
featureFeature name of the analyzed distributions. (character)
One row dataframe comprising the test results. (tibble::tibble)
wilcoxonTestFeature()Performs a comparison between the original and the imputated distribution of a given feature using a two-sided Wilcoxon/Mann-Whitney test.
pgu.validator$wilcoxonTestFeature( org = "numeric", imp = "numeric", feature = "character" )
orgOriginal data to be analzed. (numeric)
impImputed data to be analyzed. (numeric)
featureFeature name of the analyzed distributions. (character)
One row dataframe comprising the test results. (tibble::tibble)
centralMomentsFeature()Estimates estimates the central moments of the given distribution.
pgu.validator$centralMomentsFeature(values = "numeric", feature = "character")
valuesData to be analzed. (numeric)
featureFeature name of the analyzed distributions. (character)
One row dataframe comprising the statistics. (tibble::tibble)
validate()Validates the feature distributions of the original and the imputated dataframeā using a two-sided Kolmorogow-Smirnow test and a two-sided Wilcoxon/Mann-Whitney test. The result is stored in the instance variables 'testStatistics_df'and 'distributionStatistics_df'. Displays the progress if shiny is loaded.
pgu.validator$validate( org_df = "tbl_df", imp_df = "tbl_df", progress = "Progress" )
org_dfOriginal dataframe to be analzed. (tibble::tibble)
imp_dfImputed dataframe to be analyzed. (tibble::tibble)
progressIf shiny is loaded, the analysis' progress is stored in this instance of the shiny Progress class. (shiny::Progress)
featurePdf()Receives a dataframe and plots the pareto density of the features 'org_pdf' and 'imp_pdf'. Returns the plot
pgu.validator$featurePdf(data_df = "tbl_df")
data_dfdataframe to be plotted (tibble::tibble)
A ggplot2 object (ggplot2::ggplot)
featureCdf()Receives a dataframe and plost the feature 'x' against the features 'org_cdf' and 'imp_cdf'. Returns the plot
pgu.validator$featureCdf(data_df = "tbl_df")
data_dfdataframe to be plotted (tibble::tibble)
A ggplot2 object (ggplot2::ggplot)
featureVs()Receives two numeric vectors 'org' and 'imp'. Plots the qq-plot of both vectors. Returns the plot
pgu.validator$featureVs(org = "numeric", imp = "numeric")
orgNumric vector comprising the original data. (numeric)
impNumeric vector comprising the imputed data. (numeric)
A ggplot2 object (ggplot2::ggplot)
featureBoxPlot()Receives a dataframe and information about the lloq and uloq and retuns a boxplot
pgu.validator$featureBoxPlot( data_df = "tbl_df", lloq = "numeric", uloq = "numeric", feature = "character" )
data_dfDataframe to be analyzed (tibble::tibble)
lloqlower limit of quantification (numeric)
uloqupper limit of quantification (numeric)
featureFeature name (character)
A ggplot2 object (ggplot2::ggplot)
featurePlot()Receives two numeric dataframes 'org_df' and 'imp_df', and a feature name. Creates a compund plot of the validation results for the given feature.. Returns the plot
pgu.validator$featurePlot( org_df = "tbl_df", imp_df = "tbl_df", lloq = "numeric", uloq = "numeric", impIdx_df = "tbl_df", feature = "character" )
org_dfDataframe comprising the original data. (tibble::tibble)
imp_dfDataframe comprising the imputed data. (tibble::tibble)
lloqlower limit of quantification (numeric)
uloqupper limit of quantification (numeric)
impIdx_dfdataframe comprising information about imputation sites (tibble::tibble)
featureFeature name. (character)
A ggplot2 object (ggplot2::ggplot)
clone()The objects of this class are cloneable with this method.
pgu.validator$clone(deep = FALSE)
deepWhether to make a deep clone.
Sebastian Malkusch
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.