pguIMP: pguIMP

View source: R/pguIMP.R

pguIMPR Documentation

pguIMP

Description

Reproducible cleaning of biomedical laboratory data using methods of visualization, error correction and transformation implemented as interactive R-notebooks.

Usage

pguIMP()

Details

A graphical data preprocessing toolbox, named “pguIMP”, that includes a fixed sequence of preprocessing steps to enable error-free data preprocessing interactively. By implementing contemporary data processing methods including machine learning-based imputation procedures, the creation of corrected and cleaned bioanalytical datasets is ensured, which preserve data structures such as clusters better than resulting with classical methods.

Value

shiny application object

Author(s)

Sebastian Malkusch


pguIMP documentation built on Feb. 20, 2026, 5:08 p.m.