transposeTibble: transposeTibble

View source: R/transposeTibble.R

transposeTibbleR Documentation

transposeTibble

Description

Transposes a tibble This object is used by the shiny based gui and is not for use in individual R-scripts!

Usage

transposeTibble(obj = "tbl_df")

Arguments

obj

The data frame to be transposed. (numeric)

Value

The transposed data frame. (tibble:tibble)

Author(s)

Sebastian Malkusch


pguIMP documentation built on Feb. 20, 2026, 5:08 p.m.