Function that fills in all unknowns using the k Nearest
Neighbours of each case with unknows.
By default it uses the values of the neighbours and
obtains an weighted (by the distance to the case) average
of their values to fill in the unknows.
If meth='median' it uses the median/most frequent value,
instead.
Taken from
https://github.com/ltorgo/DMwR2/