| pgu.correlator | R Documentation |
An R6 class that performs pairwise correlation on the pguIMP data set.
[R6::R6Class] object.
x <- pguIMP::pgu.correlator$new()
featureNamesReturns the instance variable featureNames. (character)
setFeatureNamesSets the instance variable featureNames. It further initializes the instance variables: intercept, pIntercept, slope, pSlope. (character)
methodReturns the instance variable method. (character)
rReturns the instance variable r. (matrix)
pPearsonReturns the instance variable pPearson. (matrix)
tauReturns the instance variable tau. (matrix)
pKendallReturns the instance variable pKendall. (matrix)
rhoReturns the instance variable rho. (matrix)
pSpearmanReturns the instance variable pSpearman. (matrix)
abscissaReturns the instance variable abscissa. (character)
setAbscissaSets the instance variable abscicca to value.
ordinateReturns the instance variable ordinate. (character)
setOrdinateSets the instance variable ordinate to value.
testReturns the instance variable test. (stats::cor.test)
new()Creates and returns a new 'pgu.correlator' object.
pgu.correlator$new(data = "tbl_df")
dataThe data to be modeled. (tibble::tibble)
A new 'pgu.correlator' object. (pguIMP::pgu.correlator)
finalize()Clears the heap and indicates if instance of 'pgu.correlator' is removed from heap.
pgu.correlator$finalize()
print()Prints instance variables of a 'pgu.correlator' object.
pgu.correlator$print()
string
resetCorrelator()Performes pair-wise correlation analysis on the attributes of the data frame. Progresse is indicated by the progress object passed to the function.
pgu.correlator$resetCorrelator(data = "tbl_df", progress = "Progress")
dataDataframe with at least two numeric attributes. (tibble::tibble)
progressKeeps track of the analysis progress. (shiny::Progress)
resetMatrix()Creates a square matrix which dimension corresponds to the length of the instance variable featureNames. The matrix entries are set to a distict 'value'.
pgu.correlator$resetMatrix(value = "numeric")
valueThe value the matrix entries are set to. (numeric)
A square matrix. (matrix)
featureIdx()Determines the numerical index of the column of an attribute based on the attribute name.
pgu.correlator$featureIdx(feature = "character")
featureThe attribute's name. (character)
The attributes column index. (numeric)
calcCorrelationNumeric()Creates a correlation test between two attributes of a dataframe. The test is stored as instance variable.
pgu.correlator$calcCorrelationNumeric( abscissa = "numeric", ordinate = "numeric", method = "character" )
abscissaThe abscissa values. (numeric)
ordinateThe ordinate values. (numeric)
methodThe cname of the correlation test. Valid coiced are defined by the instance variable 'method'. (chatacter)
createCorrelationMatrixPearson()Performs the actual correlation test routine after Pearson. Iteratively runs through the attributes known to the class and calculates Pearson's correlation for each valid attribute pair. The test results are stored in the instance variables: r, pPearson. Here, pX represents the p-value of the respective parameter X. Displays the progress if shiny is loaded.
pgu.correlator$createCorrelationMatrixPearson( data = "tbl_df", progress = "Progress" )
dataThe data to be analysed. (tibble::tibble)
progressIf shiny is loaded, the analysis' progress is stored within this instance of the shiny Progress class. (shiny::Progress)
createCorrelationMatrixKendall()Performs the actual correlation test routine after Kendall. Iteratively runs through the attributes known to the class and calculates Kendall's correlation for each valid attribute pair. The test results are stored in the instance variables: tau, pKendall. Here, pX represents the p-value of the respective parameter X. Displays the progress if shiny is loaded.
pgu.correlator$createCorrelationMatrixKendall( data = "tbl_df", progress = "Progress" )
dataThe data to be analysed. (tibble::tibble)
progressIf shiny is loaded, the analysis' progress is stored within this instance of the shiny Progress class. (shiny::Progress)
createCorrelationMatrixSpearman()Performs the actual correlation test routine after Spearman. Iteratively runs through the attributes known to the class and calculates Spearman's correlation for each valid attribute pair. The test results are stored in the instance variables: rho, pSpearman. Here, pX represents the p-value of the respective parameter X. Displays the progress if shiny is loaded.
pgu.correlator$createCorrelationMatrixSpearman( data = "tbl_df", progress = "Progress" )
dataThe data to be analysed. (tibble::tibble)
progressIf shiny is loaded, the analysis' progress is stored within this instance of the shiny Progress class. (shiny::Progress)
correlate()Performs the all three correlation test routines defined within the instance variable 'method'. Displays the progress if shiny is loaded.
pgu.correlator$correlate(data = "tbl_df", progress = "Progress")
dataThe data to be analysed. (tibble::tibble)
progressIf shiny is loaded, the analysis' progress is stored within this instance of the shiny Progress class. (shiny::Progress)
printFeature()Transforms the results of the correlation procedure for a valid pair of attributes to a dataframe and returns it.
pgu.correlator$printFeature()
The analyis result as a dataframe. (tibble::tibble)
printRTbl()Transfroms instance variable 'r' to a dataframe and returns it.
pgu.correlator$printRTbl()
Dataframe of instance variable 'r'. (tibble::tibble)
printPPearsonTbl()Transfroms instance variable 'pPearson' to a dataframe and returns it.
pgu.correlator$printPPearsonTbl()
Dataframe of instance variable 'pPearson'. (tibble::tibble)
printTauTbl()Transfroms instance variable 'tau' to a dataframe and returns it.
pgu.correlator$printTauTbl()
Dataframe of instance variable 'tau'. (tibble::tibble)
printPKendallTbl()Transfroms instance variable 'pKendall' to a dataframe and returns it.
pgu.correlator$printPKendallTbl()
Dataframe of instance variable 'pKendall'. (tibble::tibble)
printRhoTbl()Transfroms instance variable 'rho' to a dataframe and returns it.
pgu.correlator$printRhoTbl()
Dataframe of instance variable 'rho'. (tibble::tibble)
printPSpearmanTbl()Transfroms instance variable 'pSpearman' to a dataframe and returns it.
pgu.correlator$printPSpearmanTbl()
Dataframe of instance variable 'pSpearman'. (tibble::tibble)
clone()The objects of this class are cloneable with this method.
pgu.correlator$clone(deep = FALSE)
deepWhether to make a deep clone.
Sebastian Malkusch
require(dplyr)
require(tibble)
data(iris)
data_df <- iris %>%
tibble::as_tibble() %>%
dplyr::select(-c("Species"))
correlator = pguIMP::pgu.correlator$new(data_df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.