Filter the pguIMP dataset.
R6::R6Class object.
colIdxReturns the instance variable colIdx (numeric)
setColIdxSets the instance variable colIdx (numeric)
rowIdxReturns the instance variable rowIdx (numeric)
setRowIdxSets the instance variable rowIdx (numeric)
new()Resets the filter parameter colIdx to the full dataframe.
Resets the filter parameter rowIdx to the full dataframe.
Clears the heap and indicates that instance of pguIMP::pgu.filter is removed from heap.
Creates and returns a new pguIMP::pgu.filter object.
pgu.filter$new(data_df = "tbl_df")
data_dfThe data to be analyzed. (tibble::tibble)
A new pguIMP::pgu.filter object. (pguIMP::pgu.filter)
print()Prints instance variables of a pguIMP::pgu.filter object.
pgu.filter$print()
string
reset()Resets the filter parameter colIdx and rowIdx to the full dataframe.
pgu.filter$reset(data_df = "tbl_df")
data_dfThe data to be analyzed. (tibble::tibble)
predict()Filters and returns the given data frame.
pgu.filter$predict(data_df = "tbl_df")
data_dfThe data to be analyzed. (tibble::tibble)
The filtered data frame (tibble::tibble)
clone()The objects of this class are cloneable with this method.
pgu.filter$clone(deep = FALSE)
deepWhether to make a deep clone.
The filtering is done by column and row indices. This object is used by the shiny based gui and is not for use in individual R-scripts!