| pgu.limitsOfQuantification | R Documentation |
Handles values in the pguIMP dataset that exceed the limits of quantification. This object is used by the shiny based gui and is not for use in individual R-scripts!
R6::R6Class object.
more information
loqReturns the instance variable loq (tibble::tibble)
setLoqSets the instance variable loq (tibble::tibble)
outliersReturns instance variable outliers (tibble::tibble)
lloqSubstituteAlphabetReturns the instance variable lloqSubstititeAlphabet (character)
lloqSubstituteAgentReturns the instance variable lloqSubstituteAgent (character)
setLloqSubstituteAgentSets the instance variable lloqSubstituteAgent (character)
uloqSubstituteAlphabetReturns the instance variable uloqSubstititeAlphabet (character)
uloqSubstituteAgentReturns the instance variable uloqSubstituteAgent (character)
setUloqSubstituteAgentSets the instance variable uloqSubstituteAgent (character)
naHandlingAlphabetReturns the instance variable naHandlingAlphabet (character)
naHandlingAgentReturns the instance variable naHandlingAgent (character)
setNaHandlingAgentSets the instance variable naHandlingAgent (character)
loqStatisticsReturns the instance variable loqStatistics
The following public methods are available:
- 'new()': Creates a new pgu.limitsOfQuantification object - 'print()': Prints instance variables - 'reset()': Resets the object - 'fit()': Analyzes data for LOQ violations - 'predict()': Applies LOQ corrections - 'attribute_lloq()', 'attribute_uloq()': Get LOQ values - 'set_attribute_lloq()', 'set_attribute_uloq()': Set LOQ values - 'attribute_outliers()': Get outliers for an attribute - 'plot_loq_distribution()': Plot LOQ statistics - 'attribute_bar_plot()', 'attribute_box_plot_with_subset()', 'attribute_plot()': Create diagnostic plots - 'clone()': Clone the object
Sebastian Malkusch
Other pguIMP classes: pgu.missings
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.