| pgu.missings | R Documentation |
Detects and substitutes missing values from data set.
R6::R6Class object.
Detects missing values in the transformed and normalized data set. This object is used by the shiny based gui and is not for use in individual R-scripts!
imputationParameterReturns the instance variable imputationParameter (tibble::tibble)
imputationSitesReturns the instance variable imputationSites (tibble::tibble)
one_hot_dfReturns the positions of missings in one_hot encoding (tibble::tibble)
amvReturns the instance variable amv (numeric)
The following public methods are available:
- 'new()': Creates a new pgu.missings object - 'print()': Prints instance variables - 'resetImputationParameter()': Resets imputation parameters - 'featureIdx()': Get feature position - 'filterFeatures()': Filter features with missings - 'gatherMeasurements()', 'gatherMissings()', 'gatherExistings()', 'gatherFractionOfMissings()': Gather missing value statistics - 'gatherImputationStatistics()': Collect imputation statistics - 'one_hot()': Create one-hot encoding of missings - 'detectImputationSites()': Detect missing value positions - 'imputationSiteDistribution()': Get missing value distribution - 'imputationSiteHeatMap()': Create missing value heatmap - 'clone()': Clone the object
Sebastian Malkusch
Other pguIMP classes: pgu.limitsOfQuantification
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.