| pgu.reporter | R Documentation |
Creates a human readable report file of the pguIMP analysis in odf format via rmarkdown and latex. This object is used by the shiny based gui and is not for use in individual R-scripts!
[R6::R6Class] object.
I run at the end of the analysis.
filenameReturns the instance variable filename (character)
setFilenameSets the instance variable filename to name. (character)
new()Creates and returns a new 'pgu.reporter' object.
pgu.reporter$new(name = "character")
nameFilename of the report pdf. (character)
A new 'pgu.reporter' object. (pguIMP::pgu.report)
finalize()Clears the heap and indicates that instance of 'pgu.reporter' is removed from heap.
pgu.reporter$finalize()
print()Prints instance variables of a 'pgu.reporter' object.
pgu.reporter$print()
string
write_report()Writes a report of the pguIMP analysis to a pdf file.
pgu.reporter$write_report(obj)
objA list of class objects that are passed to the rmarkdown script.
t.b.a.
clone()The objects of this class are cloneable with this method.
pgu.reporter$clone(deep = FALSE)
deepWhether to make a deep clone.
Sebastian Malkusch
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.