Learn R Programming

pguIMP (version 0.0.0.3)

pgu.reporter: pgu.reporter

Description

Creates a human readable report file of the pguIMP analysis in odf format via rmarkdown and latex. This object is used by the shiny based gui and is not for use in individual R-scripts!

Arguments

Format

R6::R6Class object.

Active bindings

filename

Returns the instance variable filename (character)

setFilename

Sets the instance variable filename to name. (character)

Methods

Public methods

Method new()

Creates and returns a new pgu.reporter object.

Usage

pgu.reporter$new(name = "character")

Arguments

name

Filename of the report pdf. (character)

Returns

A new pgu.reporter object. (pguIMP::pgu.report)

Method finalize()

Clears the heap and indicates that instance of pgu.reporter is removed from heap.

Usage

pgu.reporter$finalize()

Method print()

Prints instance variables of a pgu.reporter object.

Usage

pgu.reporter$print()

Returns

string

Method write_report()

Writes a report of the pguIMP analysis to a pdf file.

Usage

pgu.reporter$write_report(obj)

Arguments

obj

A list of class objects that are passed to the rmarkdown script.

Returns

t.b.a.

Method clone()

The objects of this class are cloneable with this method.

Usage

pgu.reporter$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Details

I run at the end of the analysis.