A class that keeps track of the pguIMP analysis process.
R6::R6Class object.
processAlphabetReurns the process alphabet of the pguIMP analysis routine. (character)
processStatusReturns the process status of the pguIMP routine. (logical)
new()Creates and returns a new `pgu.status`` object.
pgu.status$new()
A new pgu.status object.
(pguIMP::pgu.status)
finalize()Clears the heap and
indicates if instance of pgu.status is removed from heap.
pgu.status$finalize()
print()Prints instance variables of a pgu.status object.
pgu.status$print()
string
reset()resets the intance variables processAlphabet and processStatus to their initial values (FALSE).
pgu.status$reset()
update()updates the process status
pgu.status$update(processName = "character", value = "logical")
processNameThe name of the pguIMP process that has been performed.
(character)
valueIndicates if the process ended with success. (logical)
query()Queries if a process has already been performed successfully.
pgu.status$query(processName = "character")
processNameName of the process to be checked. (character)
Status of the queried process (logical)
clone()The objects of this class are cloneable with this method.
pgu.status$clone(deep = FALSE)
deepWhether to make a deep clone.
pguIMP uses a defined linear analysis path The current status therefore provides information about which analyses have already been performed and which still have to be performed. This way pguIMG knows any time during analysis, if all necessary information for the next desired analysis step are available. This object is used by the shiny based gui and is not for use in individual R-scripts!