View source: R/transposeTibble.R
| transposeTibble | R Documentation |
Transposes a tibble This object is used by the shiny based gui and is not for use in individual R-scripts!
transposeTibble(obj = "tbl_df")
obj |
The data frame to be transposed. (numeric) |
The transposed data frame. (tibble:tibble)
Sebastian Malkusch
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.